==> waii-sdk-java-1.28.0-sources.jar: ai/waii/clients/chat/ChatResponse.java <==
package ai.waii.clients.chat;

import com.google.gson.annotations.SerializedName;

import java.util.List;

public class ChatResponse {

    private String response;
    @SerializedName("current_step")
    private String currentStep;
    @SerializedName("response_data")
    private ChatResponseData responseData;
    @SerializedName("is_new")
    private Boolean isNew = false;
    @SerializedName("timestamp_ms")
    private long timestamp;
    @SerializedName("chat_uuid")
    private String chatUuid;
    @SerializedName("response_selected_fields")
    private List<ChatModule> responseSelectedFields;

    public List<ChatModule> getResponseSelectedFields() {
        return responseSelectedFields;
    }

    public void setResponseSelectedFields(List<ChatModule> responseSelectedFields) {
        this.responseSelectedFields = responseSelectedFields;
    }

    public String getResponse() {
        return response;
    }

    public void setResponse(String response) {
        this.response = response;
    }

    public ChatResponseData getResponseData() {
        return responseData;
    }

    public void setResponseData(ChatResponseData responseData) {
        this.responseData = responseData;
    }

    public Boolean getIsNew() {
        return isNew;
    }

    public void setIsNew(Boolean isNew) {
        this.isNew = isNew;
    }

    public long getTimestamp() {
        return timestamp;
    }

    public void setTimestamp(long timestamp) {
        this.timestamp = timestamp;
    }

    public String getChatUuid() {
        return chatUuid;
    }

    public void setChatUuid(String chatUuid) {
        this.chatUuid = chatUuid;
    }
}

==> waii-sdk-java-1.28.2-sources.jar: ai/waii/clients/chat/ChatResponse.java <==
package ai.waii.clients.chat;

import com.google.gson.annotations.SerializedName;

import java.util.List;

public class ChatResponse {

    private String response;
    @SerializedName("current_step")
    private String currentStep;
    @SerializedName("response_data")
    private ChatResponseData responseData;
    @SerializedName("is_new")
    private Boolean isNew = false;
    @SerializedName("timestamp_ms")
    private long timestamp;
    @SerializedName("chat_uuid")
    private String chatUuid;
    @SerializedName("response_selected_fields")
    private List<ChatModule> responseSelectedFields;

    @SerializedName("llm_usage_stats")
    private LLMUsageStatistics llmUsageStats;

    public LLMUsageStatistics getLlmUsageStats() {
        return llmUsageStats;
    }

    public void setLlmUsageStats(LLMUsageStatistics llmUsageStats) {
        this.llmUsageStats = llmUsageStats;
    }

    public static class LLMUsageStatistics {
        @SerializedName("token_total")
        private Integer tokenTotal;

        public Integer getTokenTotal() {
            return tokenTotal;
        }

        public void setTokenTotal(Integer tokenTotal) {
            this.tokenTotal = tokenTotal;
        }
    }

    public List<ChatModule> getResponseSelectedFields() {
        return responseSelectedFields;
    }

    public void setResponseSelectedFields(List<ChatModule> responseSelectedFields) {
        this.responseSelectedFields = responseSelectedFields;
    }

    public String getResponse() {
        return response;
    }

    public void setResponse(String response) {
        this.response = response;
    }

    public ChatResponseData getResponseData() {
        return responseData;
    }

    public void setResponseData(ChatResponseData responseData) {
        this.responseData = responseData;
    }

    public Boolean getIsNew() {
        return isNew;
    }

    public void setIsNew(Boolean isNew) {
        this.isNew = isNew;
    }

    public long getTimestamp() {
        return timestamp;
    }

    public void setTimestamp(long timestamp) {
        this.timestamp = timestamp;
    }

    public String getChatUuid() {
        return chatUuid;
    }

    public void setChatUuid(String chatUuid) {
        this.chatUuid = chatUuid;
    }
}
